##Research Questions and Approach

**Aim 1: A global census of microbial eukaryotes found in association with leaves, roots, and sediment of the seagrass Zostera marina.**

_Objectives:_ We will investigate the global diversity of microbial eukaryotes found in _Zostera marina_ beds. As part of this investigation we seek to answer the following questions: Can we detect a phylogeographic signal of _Z. marina_-associated microeukaryotes? What is driving microbial eukaryotic community compositions in _Z. marina_ beds, the presence of _Z. marina_ (host plant) or environmental factors (geography, pH, temperature, etc)? Or is everything everywhere? Do we see specific patterns in either richness or diversity in these beds and do any of these patterns mimic those of macro-organisms known to frequent _Z. marina_ beds?

_Sampling:_ We have, in hand, DNA that has been extracted from 414 samples of _Zostera marina_ leaves, roots, and sediment (ZEN samples). These samples include 3 biological replicates of each sample type. Samples were take from two seagrass beds at each of 22 sites in northern Europe, the Mediterranean, Japan, Australia, Central America, and both coasts of the United States. We have successfully amplified and sequenced the 16S ribosomal RNA genes of the microbial communities in these samples. Analysis of these samples is currently underway, and is showing very exciting results. We have also demonstrated success amplifying, sequencing, and analyzing eukaryotic microbial loci (fungal ITS) from samples prepared in the same way as the ZEN samples. We also have a wealth of metadata associated with each site: 109 measurements of plant traits (including biomass, productivity, and microsatellite loci), water and sediment characteristics, and abundances of invertebrate grazers and predator species. 

_Molecular Biology/Bioinformatic Anaylsis_: We will use universal microbial eukaryotic primers, targeting the V4 and V9 variable regions of the 18S ribosomal RNA gene. The V4 region will be amplified using the AReuk454FWD1 and TAReukREV3 primers with Illumina adaptors instead of 454 adaptors from \cite{STOECK_2010} and the V9 region will be amplified using the 1391f and EukBr primers according to the earth microbiome project protocols. The V4 and V9 regions are standardly used in such inventories and are known to be informative at the Class taxonomic level \cite{STOECK_2010}. Samples will be multiplexed and the resulting DNA libraries will be sequenced using Illumina MiSeq 250 bp paired end sequencing at the UCD Genome Center. Preprocessing and quality assessment will be performed as described by \cite{Smith_2014}. Sequence analysis will follow a similar worflow to \cite{Korajkic_2015}  with sequences analyzed using a modified QIIME, Quantitative Insights Into Microbial Ecology \cite{Caporaso_2010}, workflow using UPARSE \cite{Edgar_2013} to pick open reference operational taxonomic units (OTU’s) at 97% and 99% similarity. Taxonomy will be assigned using the RDP Classifier \cite{Wang_2007} with the SILVA rRNA database \cite{Quast_2012} and Genbank searches. Phylogenetic trees will be constructed by placing representative sequences for each _de novo_ OTU into the SILVA reference tree with RAxML. The resulting OTU matrix will be rarefied and subsequent data analysis performed in R. Alpha diversity will be calculated using a variety of metrics including the Shannon and Simpson indices to determine intrasample diversity. The beta diversity metric, Bray–Curtis dissimilarity, will be calculated for the OTU matrix to determine intersample diversity. PERMANOVA tests \cite{Anderson_2001} will be used to determine the significance of sample type (ex. sediment), location and environmental measures (salinity, temperature, etc.) on microbial eukaryotic community composition. To visualize and assess patterns of microeukayotic community structure, a nonmetric multidimensional scaling (NMDS) ordination of the Bray–Curtis dissimilarities will be created. Mantel tests will be performed to determine if correlations exist between the bacterial community composition from the 16S rRNA results and the microeukaryotic community composition we determine here. 

**Aim 2: A global census of microbial eukaryotes found in association with leaves, roots, and sediment of the Order Alismatales, which includes three, independent lineages of seagrasses**

_Objectives:_ Aim 2 seeks to expand Aim 1 to include multiple species of seagrass as well as other aquatic plant species in the Order Alismatales. This expansion will allow for investigation into additional questions including: Are there distinct microeukaryotic communities associating with different host plants? Is there evidence of a phylogenetic signal or pattern between host plant species and their microeukaryotes? For locations with multiple host species co-occurring, do we see the same or different associations? Are there any microeukaryotes that are shared between the three lineages of seagrass or unique to each lineage?

_Sampling_: We are currently leveraging our ZEN contacts to collect leaves, roots, and sediment from plants from the Order Alismatales and have funds to amplify and sequence the 16S ribosomal RNA genes of the microbial communities in these samples. Our goal is to have samples from a minimum of three representative species from each of the three seagrass lineages, three of the closest freshwater relatives for each seagrass lineage and two terrestrial outgroups for a minimum of 20 plant species. However, based on collections from our collaborators as well as local collections performed by our lab, it is very likely that we will exceed our minimum collection goal for seagrass and freshwater species. For each plant species, 5 biological replicates of root, leaf and rhizosphere sediment will be collected at a minimum of three geographic locations. 

_Molecular Biology/Bioinformatic Anaylsis_: The V4 and V9 variable regions of the 18S ribosomal RNA gene will be targeted for amplification as in Aim 1 and the same general bionifornmatic pipeline and statistical analyses methods will be performed. Addtional statistical analyses will be implemented to determine if distinct microbial communities are found in association with different host plants.

**Aim 3: Establish culture collection of microbial eukaryotes associated with Zostera marina in Bodega Bay, California.**

_Objectives:_ Environmental molecular barcoding studies offer the benefit of high-throughput biodiversity discovery, especially of organisms that are recalcitrant to laboratory culture. However, they suffer from biases during DNA extraction and PCR, and can exclude important, even dominant, taxa  \cite{HoefEmden_2012}  \cite{Baker_2003}. They also fall short of providing the means to link biodiversity discovery with functional, ecological significance. The value of DNA sequencing-based studies can be improved by augmenting them with a rich, phylogenetically diverse culture collection. Such collections enable the sequencing of isolate genomes, providing information about metabolic potential, as well as reference sequences for shotgun metagenomics. They also offer a resource for future experimental work. Culturing diverse microbial eukaryotes from seagrass beds is a labor-intensive process, requiring much time and multiple sampling efforts returning fresh samples. Therefore, we will focus our initial efforts on _Zostera marina_ beds in Bodega Bay, California, where we have full access to the Bodega Marine Laboratory and the required permits for collection. All isolates will be characterized using both microscopy and molecular methods (described below).

_Culturing/Isolation_: We broadly define microbial eukaryotes to include both single-celled and multicellular eukaryotic organisms that are invisible to the naked eye, spanning every major eukaryotic lineage. These represent tremendous metabolic diversity, including photosynthetic and non-photosynthetic, obligate anaerobes and anaerobes, free-living and parasitic. Therefore, we  will employ a wide variety of culture techniques to isolate them, including single cell sorting and enrichment cultures using seagrass rhizosphere sediments, filtered bulk seawater, and seagrass tissues as as sources (see \cite{Torta_2014}). We will use an isolation/characterization pipeline published by our lab \cite{Dunitz_2015} and focus on variety of media recipes and culture techniques to maximize diversity discovery \cite{Lee_1992}. We will also target specific taxa known to play important roles in seagrass health \cite{Muehlstein_1991} and important ecosystem services such as decomposition \cite{Newell_1996}, the carbon cycle \cite{Smetacek_1999} and primary production \cite{Field_1998} \cite{Armbrust_2009} \cite{Higgins_2012}. We have had successful experience in our lab  culturing diverse amoeba, fungi, and ciliates.  

_Phenotypic and Molecular Characterization of Isolates_: Microscopy of mature cultures will be used to record external morphology, and growth rate will be characterized at 10, 20, 30 deg C. Isolates will be fixed and imaged under natural light and then with flourescence microscopy. Fungal isolates will be stained for chitin and with fungal specific rRNA probes using flourescence in situ hybridization (FISH) as in  as in \cite{Wurzbacher_2012}. All non-fungal isolates will be stained for alpha tubulin in combination with FISH staining using a general eukaryotic rRNA probe as in \cite{Hirst_2011}. If necessary, a more specific rRNA probe may also be used based on the group-specific sequence obtained. 

Molecular taxonomic classification of isolates will be performed using barcoding, first with V4 18S rDNA, then with group-specific markers, as outlined by the CBOL Protist Working Group \cite{Pawlowski_2012}. We will employ our published bioinformatic workflow \cite{Dunitz_2015} to infer phylogenetic placement of the isolates in the context of the most closely related type strains available. 

###Data Management Plan:
All data associated with this work, including raw sequence data, images, and analytical workflows  will immediately be made publicly available on our lab website and on Figshare. All sequence data will be deposited to NCBI. After identification and imaging, isolates will be sent to both the American Tissue Culture Collection (ATCC) and the Culture Collection of Amoeba and Protozoa (CCAP), where they will be publicly available. 